local AddName, AddonTable = ...
local L = AddonTable.L

------------------------------
--		Options Equates		--
------------------------------
local Both, Enhanced, Base, World, Realm = 3, 1, 2, 1, 2


----------------------------------
--		Text Return Formats		--
----------------------------------
local Double_Rating_Format = { "%.0f", "%.0f", "%.0f/%.0f", }
local Base_Casting_Format = { "%.2f", "%.2f", "%.2f/%.2f", }


--------------------------
--		Physical		--
--------------------------
-- Speed
function AddonTable.FunctionList.Speed(HUD, data, options, ...)

	local currentSpeed, runSpeed, flightSpeed, swimSpeed = GetUnitSpeed("player")
	local fullSpeed = GetUnitSpeed("player") / 7 * 100
	if fullSpeed == 0 or fullSpeed == 100 then
		speedColor = ""
	elseif fullSpeed < 100 then
		speedColor = "|cffC41E3A"
	elseif fullSpeed > 100 then
		speedColor = "|cff00f26d"
	end
	
	HUD:UpdateText(data, speedColor .. string.format("%d%%", ("%.0f"):format(fullSpeed)))
end

function AddonTable.FunctionList.Durability(HUD, data, options, ...)
	local Durability, Current, Full, Percent
	local LowestCurrent, LowestFull, t1, t2, t3 = 500, 0, 0, 0, 100
	for i=1,19 do
		Current, Full = GetInventoryItemDurability(i)
		if Current and Full then
			Percent = floor(100*Current/Full + 0.5)
			if (Percent < t3) then
				t3 = Percent
			end
			if (Current < LowestCurrent) then
				LowestCurrent = Current
				LowestFull = Full
			end
			t1 = t1 + Current
			t2 = t2 + Full
		end
	end
	if t2 == 0 then
		Durability = "N/A"
	else
		Durability = floor(t1 * 100 / t2)
	end
	local Text = ""
	if type(Durability) == "number" then
		if Durability > 50 then
			Text = string.format("|cff%2xff00", ((Durability > 50) and (255 - 2.55*Durability) or (2.55*Durability)), Durability) .. Text
		else
			Text = string.format("|cffff%2x00", (2.55*Durability), Durability) .. Text
		end
		Text = Text..Durability.."%"
	end
	
	HUD:UpdateText(data, Text)        
end

function AddonTable.FunctionList.Lag(HUD, data, options, ...)

	local EB, percentStat, ratingStat = options.World_Realm
	local _, _, lagRealm, lagWorld = GetNetStats()
	local lagColor = ""
	local returnText

	if lagWorld <= 90 or lagRealm <= 90 then
		lagColor = "|cff71FFC9"
	elseif (lagWorld >= 90 and lagWorld < 200) or  (lagRealm >= 90 and lagRealm < 200) then
		lagColor = "|cffFF7C0A"
	elseif lagWorld >= 200 or lagRealm >= 200 then
		lagColor = "|cffC41E3A"
	end
	
	if AddonTable.Band(EB, World) then
		returnText = lagColor .. floor(lagWorld)
	end
	if  AddonTable.Band(EB, Realm) then
		returnText = lagColor .. floor(lagRealm)
	end
	if  AddonTable.Band(EB, Both) then
		returnText = lagColor .. floor(lagWorld) .. "/" .. floor(lagRealm)
	end		

	HUD:UpdateText(data, returnText)
end

function AddonTable.FunctionList.FPS(HUD, data, options, ...)

	local framerate = GetFramerate()
	local fpsColor = ""
	
	if framerate < 30 then
		fpsColor = "|cffC41E3A"
	elseif framerate > 30 and framerate < 50 then
		fpsColor = "|cffFF7C0A"
	elseif framerate > 50 then
		fpsColor = "|cff71FFC9"
	end
	
	HUD:UpdateText(data, fpsColor .. floor(framerate))
end

function AddonTable.FunctionList.Gold(HUD, data, options, ...)

	local money = GetMoney()
	local formattedMoney = (GetCoinTextureString(money))
	
	HUD:UpdateText(data, formattedMoney)
end



	
